"""
    ai/h2o/securestore/v1/oauth_client.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from h2o_secure_store.gen.api_client import ApiClient, Endpoint as _Endpoint
from h2o_secure_store.gen.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from h2o_secure_store.gen.model.o_auth_client_resource import OAuthClientResource
from h2o_secure_store.gen.model.rpc_status import RpcStatus
from h2o_secure_store.gen.model.v1_create_o_auth_client_response import V1CreateOAuthClientResponse
from h2o_secure_store.gen.model.v1_get_o_auth_client_response import V1GetOAuthClientResponse
from h2o_secure_store.gen.model.v1_list_o_auth_clients_response import V1ListOAuthClientsResponse
from h2o_secure_store.gen.model.v1_o_auth_client import V1OAuthClient
from h2o_secure_store.gen.model.v1_update_o_auth_client_response import V1UpdateOAuthClientResponse


class OAuthClientServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.o_auth_client_service_create_o_auth_client_endpoint = _Endpoint(
            settings={
                'response_type': (V1CreateOAuthClientResponse,),
                'auth': [],
                'endpoint_path': '/v1/oauthClients',
                'operation_id': 'o_auth_client_service_create_o_auth_client',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'oauth_client',
                    'oauth_client_id',
                ],
                'required': [
                    'oauth_client',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'oauth_client':
                        (V1OAuthClient,),
                    'oauth_client_id':
                        (str,),
                },
                'attribute_map': {
                    'oauth_client_id': 'oauthClientId',
                },
                'location_map': {
                    'oauth_client': 'body',
                    'oauth_client_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.o_auth_client_service_delete_o_auth_client_endpoint = _Endpoint(
            settings={
                'response_type': (bool, date, datetime, dict, float, int, list, str, none_type,),
                'auth': [],
                'endpoint_path': '/v1/{name}',
                'operation_id': 'o_auth_client_service_delete_o_auth_client',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'name',
                ],
                'required': [
                    'name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name',
                ]
            },
            root_map={
                'validations': {
                    ('name',): {

                        'regex': {
                            'pattern': r'oauthClients\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name':
                        (str,),
                },
                'attribute_map': {
                    'name': 'name',
                },
                'location_map': {
                    'name': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.o_auth_client_service_get_o_auth_client_endpoint = _Endpoint(
            settings={
                'response_type': (V1GetOAuthClientResponse,),
                'auth': [],
                'endpoint_path': '/v1/{name}',
                'operation_id': 'o_auth_client_service_get_o_auth_client',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'name',
                ],
                'required': [
                    'name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name',
                ]
            },
            root_map={
                'validations': {
                    ('name',): {

                        'regex': {
                            'pattern': r'oauthClients\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name':
                        (str,),
                },
                'attribute_map': {
                    'name': 'name',
                },
                'location_map': {
                    'name': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.o_auth_client_service_invalidate_token_sources_endpoint = _Endpoint(
            settings={
                'response_type': (bool, date, datetime, dict, float, int, list, str, none_type,),
                'auth': [],
                'endpoint_path': '/v1/{name}:invalidateTokenSources',
                'operation_id': 'o_auth_client_service_invalidate_token_sources',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'name',
                    'body',
                ],
                'required': [
                    'name',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name',
                ]
            },
            root_map={
                'validations': {
                    ('name',): {

                        'regex': {
                            'pattern': r'oauthClients\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name':
                        (str,),
                    'body':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                },
                'attribute_map': {
                    'name': 'name',
                },
                'location_map': {
                    'name': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.o_auth_client_service_list_o_auth_clients_endpoint = _Endpoint(
            settings={
                'response_type': (V1ListOAuthClientsResponse,),
                'auth': [],
                'endpoint_path': '/v1/oauthClients',
                'operation_id': 'o_auth_client_service_list_o_auth_clients',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'page_size',
                    'page_token',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'page_size':
                        (int,),
                    'page_token':
                        (str,),
                },
                'attribute_map': {
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                },
                'location_map': {
                    'page_size': 'query',
                    'page_token': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.o_auth_client_service_update_o_auth_client_endpoint = _Endpoint(
            settings={
                'response_type': (V1UpdateOAuthClientResponse,),
                'auth': [],
                'endpoint_path': '/v1/{oauthClient.name}',
                'operation_id': 'o_auth_client_service_update_o_auth_client',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'oauth_client_name',
                    'update_mask',
                    'oauth_client',
                ],
                'required': [
                    'oauth_client_name',
                    'update_mask',
                    'oauth_client',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'oauth_client_name',
                ]
            },
            root_map={
                'validations': {
                    ('oauth_client_name',): {

                        'regex': {
                            'pattern': r'oauthClients\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'oauth_client_name':
                        (str,),
                    'update_mask':
                        (str,),
                    'oauth_client':
                        (OAuthClientResource,),
                },
                'attribute_map': {
                    'oauth_client_name': 'oauthClient.name',
                    'update_mask': 'updateMask',
                },
                'location_map': {
                    'oauth_client_name': 'path',
                    'update_mask': 'query',
                    'oauth_client': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def o_auth_client_service_create_o_auth_client(
        self,
        oauth_client,
        **kwargs
    ):
        """Creates a new OAuthClient.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.o_auth_client_service_create_o_auth_client(oauth_client, async_req=True)
        >>> result = thread.get()

        Args:
            oauth_client (V1OAuthClient): Required. The OAuthClient resource to create.

        Keyword Args:
            oauth_client_id (str): Optional. Specify the OAuthClient ID, which will become a part of the OAuthClient resource name. If not specified, the server will generate one.  It must: - contain 1-63 characters - contain only lowercase alphanumeric characters or hyphen ('-') - start with an alphabetic character - end with an alphanumeric character  This matches a regular expression: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1CreateOAuthClientResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['oauth_client'] = \
            oauth_client
        return self.o_auth_client_service_create_o_auth_client_endpoint.call_with_http_info(**kwargs)

    def o_auth_client_service_delete_o_auth_client(
        self,
        name,
        **kwargs
    ):
        """Deletes an OAuthClient and all child resources like Tokens and TokenSources.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.o_auth_client_service_delete_o_auth_client(name, async_req=True)
        >>> result = thread.get()

        Args:
            name (str): Required. OAuthClient resource name. Format: oauthClients/{oauthClient}

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            bool, date, datetime, dict, float, int, list, str, none_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name'] = \
            name
        return self.o_auth_client_service_delete_o_auth_client_endpoint.call_with_http_info(**kwargs)

    def o_auth_client_service_get_o_auth_client(
        self,
        name,
        **kwargs
    ):
        """Returns a specific OAuthClient.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.o_auth_client_service_get_o_auth_client(name, async_req=True)
        >>> result = thread.get()

        Args:
            name (str): Required. The name of the OAuthClient to retrieve. Format: `oauthClients/{oauthClient}`

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1GetOAuthClientResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name'] = \
            name
        return self.o_auth_client_service_get_o_auth_client_endpoint.call_with_http_info(**kwargs)

    def o_auth_client_service_invalidate_token_sources(
        self,
        name,
        body,
        **kwargs
    ):
        """Invalidates all child token sources.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.o_auth_client_service_invalidate_token_sources(name, body, async_req=True)
        >>> result = thread.get()

        Args:
            name (str): Required. OAuthClient resource name. Format: oauthClients/{oauthClient}
            body (bool, date, datetime, dict, float, int, list, str, none_type):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            bool, date, datetime, dict, float, int, list, str, none_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name'] = \
            name
        kwargs['body'] = \
            body
        return self.o_auth_client_service_invalidate_token_sources_endpoint.call_with_http_info(**kwargs)

    def o_auth_client_service_list_o_auth_clients(
        self,
        **kwargs
    ):
        """Returns a collection of OAuthClients.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.o_auth_client_service_list_o_auth_clients(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            page_size (int): Optional. Maximum number of OAuthClients to return in a response. If unspecified (or set to 0), at most 50 OAuthClients will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.. [optional]
            page_token (str): Optional. Leave unset to receive the initial page. To list any subsequent pages use the value of 'next_page_token' returned from the ListOAuthClientsResponse.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1ListOAuthClientsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.o_auth_client_service_list_o_auth_clients_endpoint.call_with_http_info(**kwargs)

    def o_auth_client_service_update_o_auth_client(
        self,
        oauth_client_name,
        update_mask,
        oauth_client,
        **kwargs
    ):
        """(-- api-linter: core::0134::method-signature=disabled     aip.dev/not-precedent: oauth not o_auth --) (-- api-linter: core::0134::http-uri-name=disabled     aip.dev/not-precedent: oauth not o_auth --) (-- api-linter: core::0134::http-body=disabled     aip.dev/not-precedent: oauth not o_auth  --) Updates an OAuthClient.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.o_auth_client_service_update_o_auth_client(oauth_client_name, update_mask, oauth_client, async_req=True)
        >>> result = thread.get()

        Args:
            oauth_client_name (str): Output only. Resource name. Format: oauthClients/{oauthClient}
            update_mask (str): The list of paths referencing which fields to update. Update mask must be non-empty.  Allowed field paths are: {\"display_name\", \"extra_scopes\", \"refresh_disabled\", \"login_principal_claim\"}. Paths are case sensitive (must match exactly).  To update all allowed fields, specify exactly one path with value \"*\".
            oauth_client (OAuthClientResource): OAuthClient resource.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1UpdateOAuthClientResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['oauth_client_name'] = \
            oauth_client_name
        kwargs['update_mask'] = \
            update_mask
        kwargs['oauth_client'] = \
            oauth_client
        return self.o_auth_client_service_update_o_auth_client_endpoint.call_with_http_info(**kwargs)




import http

import pytest

from h2o_secure_store.clients.base.workspace import DEFAULT_WORKSPACE
from h2o_secure_store.clients.secret.client import SecretClient
from h2o_secure_store.clients.secret_version.client import SecretVersionClient
from h2o_secure_store.clients.secret_version.secret_version import SecretVersion
from h2o_secure_store.exception import CustomApiException


def test_get_secret_version(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    secret_version = user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )

    secret_version_get = user_secret_version_client.get_secret_version(
        name=f"{DEFAULT_WORKSPACE}/secrets/{secret_user.get_secret_id()}/versions/{secret_version.get_secret_version_id()}"
    )

    assert secret_version_get.name == f"workspaces/{secret_user.get_workspace_id()}/secrets/{secret_user.get_secret_id()}/versions/{secret_version.get_secret_version_id()}"
    assert secret_version_get.value == b""  # Value is not returned in the response.
    assert secret_version_get.creator == secret_version.creator
    assert secret_version_get.create_time == secret_version.create_time
    assert secret_version_get.uid == secret_version.uid


def test_get_latest_secret_version(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )

    latest_secret_version = user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )

    secret_version_get = user_secret_version_client.get_secret_version(
        name=f"{DEFAULT_WORKSPACE}/secrets/{secret_user.get_secret_id()}/versions/latest"
    )

    assert secret_version_get.name == f"workspaces/{secret_user.get_workspace_id()}/secrets/{secret_user.get_secret_id()}/versions/{latest_secret_version.get_secret_version_id()}"


def test_get_secret_version_not_found(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.get_secret_version(
            name=f"{DEFAULT_WORKSPACE}/secrets/{secret_user.get_secret_id()}/versions/non-existent"
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_get_latest_secret_version_not_found(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.get_secret_version(
            name=f"{DEFAULT_WORKSPACE}/secrets/{secret_user.get_secret_id()}/versions/latest"
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_get_secret_version_not_found_parent(
        delete_secret_rows_before,
        user_secret_version_client: SecretVersionClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.get_secret_version(
            name=f"{DEFAULT_WORKSPACE}/secrets/non-existent/versions/non-existent"
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_get_secret_version_deleted_parent(
        delete_secret_rows_before,
        secret_user,
        user_secret_client: SecretClient,
        user_secret_version_client: SecretVersionClient,
):
    secret_version = user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )
    user_secret_client.delete_secret(name=secret_user.name)

    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.get_secret_version(
            name=f"{DEFAULT_WORKSPACE}/secrets/{secret_user.get_secret_id()}/versions/{secret_version.get_secret_version_id()}"
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND



import http

import pytest

from h2o_secure_store.exception import CustomApiException


@pytest.mark.parametrize(
    ["page_size", "page_token"],
    [
        (-20, ""),
        (0, "non-existing-token"),
    ],
)
def test_list_oauth_clients_validation(super_admin_oauth_client_client, page_size, page_token):
    with pytest.raises(CustomApiException) as exc:
        super_admin_oauth_client_client.list_oauth_clients(
            page_size=page_size,
            page_token=page_token,
        )
    assert exc.value.status == http.HTTPStatus.BAD_REQUEST


def test_list_oauth_clients_pagination(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
    oauth_client1,
    oauth_client2,
    oauth_client3,
):
    # Test getting first page.
    page = super_admin_oauth_client_client.list_oauth_clients(page_size=1)
    assert len(page.oauth_clients) == 1
    assert page.next_page_token != ""

    # Test getting second page.
    page = super_admin_oauth_client_client.list_oauth_clients(
        page_size=1,
        page_token=page.next_page_token,
    )
    assert len(page.oauth_clients) == 1
    assert page.next_page_token != ""

    # Test getting last page.
    # Test getting second page.
    page = super_admin_oauth_client_client.list_oauth_clients(
        page_size=1,
        page_token=page.next_page_token,
    )
    assert len(page.oauth_clients) == 1
    assert page.next_page_token == ""

    # Test exceeding max page size.
    page = super_admin_oauth_client_client.list_oauth_clients(page_size=5000)
    assert len(page.oauth_clients) == 3
    assert page.next_page_token == ""


def test_list_all_oauth_clients(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
    oauth_client1,
    oauth_client2,
    oauth_client3,
):
    oauth_clients = super_admin_oauth_client_client.list_all_oauth_clients()
    assert len(oauth_clients) == 3
    assert oauth_clients[0].oauth_client_id == oauth_client3.oauth_client_id
    assert oauth_clients[1].oauth_client_id == oauth_client2.oauth_client_id
    assert oauth_clients[2].oauth_client_id == oauth_client1.oauth_client_id


import http
import json

import pytest

from h2o_secure_store.exception import CustomApiException


def test_create_oauth_client(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
):
    oauth_client = super_admin_oauth_client_client.create_oauth_client(
        issuer="issuer1",
        client_id="client1",
        oauth_client_id="oauth-client1",
        authorization_endpoint="authz-endpoint",
        token_endpoint="token-endpoint",
    )

    assert oauth_client.issuer == "issuer1"
    assert oauth_client.client_id == "client1"
    assert oauth_client.name == "oauthClients/oauth-client1"
    assert oauth_client.display_name == ""
    assert oauth_client.client_secret == ""
    assert oauth_client.client_secret_set is False
    assert oauth_client.authorization_endpoint == "authz-endpoint"
    assert oauth_client.token_endpoint == "token-endpoint"
    assert oauth_client.extra_scopes == []
    assert oauth_client.refresh_disabled is False
    assert oauth_client.login_principal_claim == "preferred_username"
    assert oauth_client.callback_uri != ""
    assert oauth_client.creator != ""
    assert oauth_client.updater == ""
    assert oauth_client.create_time is not None
    assert oauth_client.update_time is None
    assert oauth_client.uid != ""


def test_create_oauth_client_already_exists(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
):
    super_admin_oauth_client_client.create_oauth_client(
        issuer="issuer1",
        client_id="client1",
        oauth_client_id="oauth-client1",
        authorization_endpoint="authz-endpoint",
        token_endpoint="token-endpoint",
    )

    with pytest.raises(CustomApiException) as exc:
        super_admin_oauth_client_client.create_oauth_client(
            issuer="issuer1",
            client_id="client1",
            oauth_client_id="oauth-client1",
            authorization_endpoint="authz-endpoint",
            token_endpoint="token-endpoint",
        )

    # grpc AlreadyExists == http Conflict 409
    assert exc.value.status == http.HTTPStatus.CONFLICT


def test_create_oauth_client_autogenerated_id(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
):
    oauth_client = super_admin_oauth_client_client.create_oauth_client(
        issuer="issuer1",
        client_id="client1",
        authorization_endpoint="authz-endpoint",
        token_endpoint="token-endpoint",
    )
    assert oauth_client.oauth_client_id != ""


def test_create_oauth_default_endpoints(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
):
    # authorization_endpoint and token_endpoint are set by server by discovering the endpoints from the issuer.
    # Using dev-okta for that.
    oauth_client = super_admin_oauth_client_client.create_oauth_client(
        issuer="http://keycloak:9080/realms/hac-dev",
        client_id="test-client",
        client_secret="test-secret",
    )

    assert oauth_client.issuer == "http://keycloak:9080/realms/hac-dev"
    assert oauth_client.client_id == "test-client"
    assert oauth_client.client_secret == ""
    assert oauth_client.client_secret_set is True
    assert oauth_client.authorization_endpoint == 'http://keycloak:9080/realms/hac-dev/protocol/openid-connect/auth'
    assert oauth_client.token_endpoint == 'http://keycloak:9080/realms/hac-dev/protocol/openid-connect/token'


def test_create_oauth_client_validation(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
):

    with pytest.raises(CustomApiException) as exc:
        super_admin_oauth_client_client.create_oauth_client(
            issuer="issuer1",
            client_id="client1",
            oauth_client_id="oauth-client1",
            authorization_endpoint="authz-endpoint",
            token_endpoint="token-endpoint",
            extra_scopes=["openid"]
        )
    assert exc.value.status == http.HTTPStatus.BAD_REQUEST
    assert 'extraScope "openid" is forbidden' in json.loads(exc.value.body)["message"]





"""
    ai/h2o/securestore/v1/oauth_client.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from h2o_secure_store.gen.api_client import ApiClient, Endpoint as _Endpoint
from h2o_secure_store.gen.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from h2o_secure_store.gen.model.rpc_status import RpcStatus
from h2o_secure_store.gen.model.v1_create_secret_version_response import V1CreateSecretVersionResponse
from h2o_secure_store.gen.model.v1_get_secret_version_response import V1GetSecretVersionResponse
from h2o_secure_store.gen.model.v1_list_secret_versions_response import V1ListSecretVersionsResponse
from h2o_secure_store.gen.model.v1_reveal_secret_version_value_response import V1RevealSecretVersionValueResponse
from h2o_secure_store.gen.model.v1_secret_version import V1SecretVersion


class SecretVersionServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.secret_version_service_create_secret_version_endpoint = _Endpoint(
            settings={
                'response_type': (V1CreateSecretVersionResponse,),
                'auth': [],
                'endpoint_path': '/v1/{parent}/versions',
                'operation_id': 'secret_version_service_create_secret_version',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'parent',
                    'secret_version',
                ],
                'required': [
                    'parent',
                    'secret_version',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'parent',
                ]
            },
            root_map={
                'validations': {
                    ('parent',): {

                        'regex': {
                            'pattern': r'workspaces\/[^\/]+\/secrets\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'parent':
                        (str,),
                    'secret_version':
                        (V1SecretVersion,),
                },
                'attribute_map': {
                    'parent': 'parent',
                },
                'location_map': {
                    'parent': 'path',
                    'secret_version': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.secret_version_service_get_secret_version_endpoint = _Endpoint(
            settings={
                'response_type': (V1GetSecretVersionResponse,),
                'auth': [],
                'endpoint_path': '/v1/{name_2}',
                'operation_id': 'secret_version_service_get_secret_version',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'name_2',
                ],
                'required': [
                    'name_2',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name_2',
                ]
            },
            root_map={
                'validations': {
                    ('name_2',): {

                        'regex': {
                            'pattern': r'workspaces\/[^\/]+\/secrets\/[^\/]+\/versions\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name_2':
                        (str,),
                },
                'attribute_map': {
                    'name_2': 'name_2',
                },
                'location_map': {
                    'name_2': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.secret_version_service_list_secret_versions_endpoint = _Endpoint(
            settings={
                'response_type': (V1ListSecretVersionsResponse,),
                'auth': [],
                'endpoint_path': '/v1/{parent}/versions',
                'operation_id': 'secret_version_service_list_secret_versions',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'parent',
                    'page_size',
                    'page_token',
                ],
                'required': [
                    'parent',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'parent',
                ]
            },
            root_map={
                'validations': {
                    ('parent',): {

                        'regex': {
                            'pattern': r'workspaces\/[^\/]+\/secrets\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'parent':
                        (str,),
                    'page_size':
                        (int,),
                    'page_token':
                        (str,),
                },
                'attribute_map': {
                    'parent': 'parent',
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                },
                'location_map': {
                    'parent': 'path',
                    'page_size': 'query',
                    'page_token': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.secret_version_service_reveal_secret_version_value_endpoint = _Endpoint(
            settings={
                'response_type': (V1RevealSecretVersionValueResponse,),
                'auth': [],
                'endpoint_path': '/v1/{name}:revealValue',
                'operation_id': 'secret_version_service_reveal_secret_version_value',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'name',
                ],
                'required': [
                    'name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name',
                ]
            },
            root_map={
                'validations': {
                    ('name',): {

                        'regex': {
                            'pattern': r'workspaces\/[^\/]+\/secrets\/[^\/]+\/versions\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name':
                        (str,),
                },
                'attribute_map': {
                    'name': 'name',
                },
                'location_map': {
                    'name': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def secret_version_service_create_secret_version(
        self,
        parent,
        secret_version,
        **kwargs
    ):
        """Creates a new SecretVersion containing secret data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.secret_version_service_create_secret_version(parent, secret_version, async_req=True)
        >>> result = thread.get()

        Args:
            parent (str): Required. The resource name of the Secret to associate with the SecretVersion. Format: `workspaces/*/secrets/*`  Authorization requires the following permission on the specified resource parent: * actions/securestore/versions/CREATE
            secret_version (V1SecretVersion): Required. The SecretVersion resource to create.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1CreateSecretVersionResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['parent'] = \
            parent
        kwargs['secret_version'] = \
            secret_version
        return self.secret_version_service_create_secret_version_endpoint.call_with_http_info(**kwargs)

    def secret_version_service_get_secret_version(
        self,
        name_2,
        **kwargs
    ):
        """Gets metadata for a SecretVersion. \"workspaces/*/secrets/*/versions/latest\" is an alias for the most recently created SecretVersion.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.secret_version_service_get_secret_version(name_2, async_req=True)
        >>> result = thread.get()

        Args:
            name_2 (str): Required. The resource name of the SecretVersion. Format: `secrets/*/versions/*`  `secrets/*/versions/latest` is an alias for the most recently created SecretVersion.  Authorization requires the following permission on the specified resource name: * `actions/securestore/versions/GET`

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1GetSecretVersionResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name_2'] = \
            name_2
        return self.secret_version_service_get_secret_version_endpoint.call_with_http_info(**kwargs)

    def secret_version_service_list_secret_versions(
        self,
        parent,
        **kwargs
    ):
        """Lists SecretVersions. This call does not return secret data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.secret_version_service_list_secret_versions(parent, async_req=True)
        >>> result = thread.get()

        Args:
            parent (str): Required. The resource name of the Secret associated with the SecretVersions to list. Format: `workspaces/*/secrets/*`  Authorization requires the following permission on the specified resource parent: * `actions/securestore/versions/LIST`

        Keyword Args:
            page_size (int): Optional. The maximum number of results to be returned in a single page. If unspecified (or set to 0), the server decides the number of results to return. If the number is greater than 1000, it is capped at 1000.. [optional]
            page_token (str): Optional. Pagination token, returned in `ListSecretVersions.next_page_token`.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1ListSecretVersionsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['parent'] = \
            parent
        return self.secret_version_service_list_secret_versions_endpoint.call_with_http_info(**kwargs)

    def secret_version_service_reveal_secret_version_value(
        self,
        name,
        **kwargs
    ):
        """Reveals the value of a SecretVersion. This call returns the secret data. \"workspaces/*/secrets/*/versions/latest\" is an alias for the most recently created SecretVersion.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.secret_version_service_reveal_secret_version_value(name, async_req=True)
        >>> result = thread.get()

        Args:
            name (str): Required. The resource name of the Secret to associate with the SecretVersion. Format: `workspaces/*/secrets/*/versions/*`  `workspaces/*/secrets/*/versions/latest` is an alias to the most recently created SecretVersion.  Authorization requires the following permission on the specified resource parent: * actions/securestore/versions/REVEALVALUE

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1RevealSecretVersionValueResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name'] = \
            name
        return self.secret_version_service_reveal_secret_version_value_endpoint.call_with_http_info(**kwargs)




import http

import pytest

from h2o_secure_store.clients.oauth_client.oauth_client import OAuthClient
from h2o_secure_store.clients.token_source.client import TokenSourceClient
from h2o_secure_store.exception import CustomApiException


def test_delete_token_source(
    delete_all_token_sources_before_after,
    oauth_client1: OAuthClient,
    user_token_source_client: TokenSourceClient,
):
    token_source = user_token_source_client.create_token_source(
        oauth_client_id=oauth_client1.oauth_client_id,
        redirect_uri="http://localhost:8080",
        token_source_id="token-source-delete",
    )

    user_token_source_client.delete_token_source(
        token_source_id=token_source.token_source_id, oauth_client_id=oauth_client1.oauth_client_id
    )

    with pytest.raises(CustomApiException) as exc:
        user_token_source_client.delete_token_source(
            token_source_id="oauth-client1", oauth_client_id=oauth_client1.oauth_client_id
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_delete_token_source_not_found(
    delete_all_token_sources_before_after,
    oauth_client1: OAuthClient,
    user_token_source_client: TokenSourceClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_token_source_client.delete_token_source(
            token_source_id="non-existing", oauth_client_id=oauth_client1.oauth_client_id
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_delete_token_source_forbidden(
        delete_all_token_sources_before_after,
        token_source1,
        super_admin_token_source_client: TokenSourceClient,
):
    with pytest.raises(CustomApiException) as exc:
        # token_source1 is created with user_token_source_client - different user
        super_admin_token_source_client.delete_token_source(
            token_source_id=token_source1.token_source_id, oauth_client_id=token_source1.oauth_client_id
        )
    assert exc.value.status == http.HTTPStatus.FORBIDDEN



import http

import pytest

from h2o_secure_store.clients.base.workspace import DEFAULT_WORKSPACE
from h2o_secure_store.clients.secret.client import SecretClient
from h2o_secure_store.clients.secret.state import SecretState
from h2o_secure_store.exception import CustomApiException


def test_delete_secret(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
):
    s = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1",
    )

    deleted = user_secret_client.delete_secret(name=s.name)

    assert deleted.name == f"workspaces/{s.get_workspace_id()}/secrets/secret1"
    assert deleted.state == SecretState.STATE_DELETED
    assert deleted.creator != ""
    assert deleted.create_time is not None
    assert deleted.delete_time is not None
    assert deleted.purge_time is not None
    assert deleted.deleter == deleted.creator

    assert deleted.delete_time > deleted.create_time
    assert deleted.purge_time > deleted.delete_time


def test_delete_deleted_secret(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
):
    s = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1",
    )

    user_secret_client.delete_secret(name=s.name)

    with pytest.raises(CustomApiException) as exc:
        user_secret_client.delete_secret(name=s.name)
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_delete_secret_not_found(
        user_secret_client: SecretClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_client.delete_secret(name=f"{DEFAULT_WORKSPACE}/secrets/non-existing")
    assert exc.value.status == http.HTTPStatus.NOT_FOUND



import pprint

from h2o_secure_store.clients.token_source.token_source import from_api_object
from h2o_secure_store.gen.model.v1_list_token_sources_response import (
    V1ListTokenSourcesResponse,
)


class TokenSourcesPage:
    """Class represents a list of TokenSources together with a next_page_token for listing all TokenSources."""

    def __init__(self, list_api_response: V1ListTokenSourcesResponse) -> None:
        api_objects = list_api_response.token_sources
        self.token_sources = []
        for api_token_source in api_objects:
            self.token_sources.append(from_api_object(api_token_source))

        self.next_page_token = list_api_response.next_page_token

    def __repr__(self) -> str:
        return pprint.pformat(self.__dict__)



from typing import List
from typing import Optional

from h2o_secure_store.clients.auth.token_api_client import TokenApiClient
from h2o_secure_store.clients.connection_config import ConnectionConfig
from h2o_secure_store.clients.oauth_client.oauth_client import OAuthClient
from h2o_secure_store.clients.oauth_client.oauth_client import from_api_object
from h2o_secure_store.clients.oauth_client.page import OAuthClientsPage
from h2o_secure_store.exception import CustomApiException
from h2o_secure_store.gen import ApiException
from h2o_secure_store.gen import Configuration
from h2o_secure_store.gen.api.o_auth_client_service_api import OAuthClientServiceApi
from h2o_secure_store.gen.model.v1_list_o_auth_clients_response import (
    V1ListOAuthClientsResponse,
)
from h2o_secure_store.gen.model.v1_o_auth_client import V1OAuthClient


class OAuthClientClient:
    """OAuthClientClient manages OAuthClients."""

    def __init__(
            self,
            connection_config: ConnectionConfig,
            verify_ssl: bool = True,
            ssl_ca_cert: Optional[str] = None,
    ):
        configuration = Configuration(host=connection_config.server_url)
        configuration.verify_ssl = verify_ssl
        configuration.ssl_ca_cert = ssl_ca_cert

        with TokenApiClient(
                configuration, connection_config.token_provider
        ) as api_client:
            self.api_instance = OAuthClientServiceApi(api_client)

    def create_oauth_client(
            self,
            issuer: str,
            client_id: str,
            oauth_client_id: str = "",
            authorization_endpoint: str = "",
            token_endpoint: str = "",
            extra_scopes: List[str] = None,
            refresh_disabled: bool = False,
            login_principal_claim: str = "",
            client_secret: str = "",
            display_name: str = "",
    ) -> OAuthClient:
        """Creates a OAuthClient.

        Args:
            issuer (str): The issuer URL of the OAuthClient.
                It is the URI of the IDP that the OAuth Client is registered with.
                In Okta it is the Authorization Server Issuer URI.
                For example, "https://dev-123456.okta.com/oauth2/ausads85d7".
            client_id (str): The client ID of the OAuthClient.
            oauth_client_id (str, optional): The ID to use for the OAuthClient, which will become the final component of the oauth_client's resource name.
                If left unspecified, the server will generate one.
                This value must:

                - contain 1-63 characters
                - contain only lowercase alphanumeric characters or hyphen ('-')
                - start with an alphabetic character
                - end with an alphanumeric character
            authorization_endpoint (str, optional): The authorization endpoint of the OAuthClient.
                For example, "https://dev-123456.okta.com/oauth2/ausads85d7/v1/authorize".
                If not set, it is discovered from the issuer.
            token_endpoint (str, optional): The token endpoint of the OAuthClient.
                For example, "https://dev-123456.okta.com/oauth2/ausads85d7/v1/token".
                If not set, it is discovered from the issuer.
            extra_scopes (List[str], optional): Extra scopes for the OAuthClient.
                Optional. A list of additional scopes to request from the OAuth Client.
                The "openid" scope is always included and does not need to be specified.
                The "offline_access" scope is included if "refresh_disabled" is not set.
                Please note that:
                The "profile" scope is strongly recommended if "login_principal_claim" is not set to "sub".
                The "email" scope is strongly recommended if "login_principal_claim" is set to "email".
                Recommended to set as ["profile", "email"].
            refresh_disabled (bool, optional): If set to true, the "offline_access" scope is not requested.
                This means that the TokenSource will not be able to refresh tokens.
                When the Token expires, the user will need to log in again.
                Defaults to false.
            login_principal_claim (str, optional): The ID Token claim name for the login principal.
                Once the login is successful, it is extracted into TokenProvider.login_principal field.
                Defaults to "preferred_username".
            client_secret (str, optional): The client secret of the OAuthClient.
            display_name (str, optional): Human-readable name of the OAuthClient. Must contain at most 63 characters. Does not have to be unique.

        Returns:
            OAuthClient: OAuthClient object.
        """
        if extra_scopes is None:
            extra_scopes = []

        api_object = V1OAuthClient(
            display_name=display_name,
            client_secret=client_secret,
            issuer=issuer,
            client_id=client_id,
            authorization_endpoint=authorization_endpoint,
            token_endpoint=token_endpoint,
            extra_scopes=extra_scopes,
            refresh_disabled=refresh_disabled,
            login_principal_claim=login_principal_claim,
        )
        created_api_object: V1OAuthClient

        try:
            created_api_object = self.api_instance.o_auth_client_service_create_o_auth_client(
                oauth_client=api_object, oauth_client_id=oauth_client_id
            ).oauth_client
        except ApiException as e:
            raise CustomApiException(e)
        return from_api_object(api_object=created_api_object)

    def get_oauth_client(self, oauth_client_id: str) -> OAuthClient:
        """Returns a OAuthClient.

        Args:
            oauth_client_id (str): OAuthClient ID.

        Returns:
            OAuthClient: OAuthClient object.
        """
        api_object: V1OAuthClient

        try:
            api_object = self.api_instance.o_auth_client_service_get_o_auth_client(
                name=self.build_resource_name(resource_id=oauth_client_id)
            ).oauth_client
        except ApiException as e:
            raise CustomApiException(e)

        return from_api_object(api_object=api_object)

    def update_oauth_client(self, oauth_client: OAuthClient, update_mask: str = "*") -> OAuthClient:
        """Updates a OAuthClient.

        Args:
            oauth_client (OAuthClient): OAuthClient object with updated fields.
            update_mask (str, optional): The field mask to use for the update.
                Allowed field paths are: {"display_name", "extra_scopes", "refresh_disabled", "login_principal_claim"}.

                If not set, all fields will be updated.
                Defaults to "*".

        Returns:
            OAuthClient: Updated OAuthClient object.
        """
        updated_api_object: V1OAuthClient

        try:
            updated_api_object = (
                self.api_instance.o_auth_client_service_update_o_auth_client(
                    oauth_client_name=oauth_client.name,
                    update_mask=update_mask,
                    oauth_client=oauth_client.to_resource(),
                ).oauth_client
            )
        except ApiException as e:
            raise CustomApiException(e)

        return from_api_object(api_object=updated_api_object)

    def invalidate_token_sources(self, oauth_client_id: str) -> None:
        """Invalidates all TokenSources for a OAuthClient.

        Args:
            oauth_client_id (str): OAuthClient ID.
        """
        try:
            self.api_instance.o_auth_client_service_invalidate_token_sources(
                name=self.build_resource_name(resource_id=oauth_client_id),
                body=None,
            )
        except ApiException as e:
            raise CustomApiException(e)

    def list_oauth_clients(
            self,
            page_size: int = 0,
            page_token: str = "",
    ) -> OAuthClientsPage:
        """Lists OAuthClients.

        Args:
            page_size (int): Maximum number of OAuthClients to return in a response.
                If unspecified (or set to 0), at most 50 OAuthClients will be returned.
                The maximum value is 1000; values above 1000 will be coerced to 1000.
            page_token (str): Page token.
                Leave unset to receive the initial page.
                To list any subsequent pages use the value of 'next_page_token' returned from the OAuthClientsPage.

        Returns:
            OAuthClientsPage: OAuthClientsPage object.
        """
        list_response: V1ListOAuthClientsResponse

        try:
            list_response = (
                self.api_instance.o_auth_client_service_list_o_auth_clients(
                    page_size=page_size,
                    page_token=page_token,
                )
            )
        except ApiException as e:
            raise CustomApiException(e)

        return OAuthClientsPage(list_response)

    def list_all_oauth_clients(self) -> List[OAuthClient]:
        """ List all OAuthClients.

        Returns:
            List of OAuthClient.
        """
        all_oauth_clients: List[OAuthClient] = []
        next_page_token = ""
        while True:
            oauth_client_list = self.list_oauth_clients(
                page_size=0,
                page_token=next_page_token,
            )
            all_oauth_clients = all_oauth_clients + oauth_client_list.oauth_clients
            next_page_token = oauth_client_list.next_page_token
            if next_page_token == "":
                break

        return all_oauth_clients

    def delete_oauth_client(self, oauth_client_id: str) -> None:
        """Deletes a OAuthClient.

        Args:
            oauth_client_id (str): OAuthClient ID.
        """
        try:
            self.api_instance.o_auth_client_service_delete_o_auth_client(
                name=self.build_resource_name(resource_id=oauth_client_id)
            )
        except ApiException as e:
            raise CustomApiException(e)

    def delete_all_oauth_clients(self) -> None:
        """Delete all OAuthClients."""
        for n in self.list_all_oauth_clients():
            self.delete_oauth_client(oauth_client_id=n.oauth_client_id)

    @staticmethod
    def build_resource_name(resource_id: str) -> str:
        """Helper function for building resource name."""
        return f"oauthClients/{resource_id}"



from enum import Enum

from h2o_secure_store.gen.model.secret_state import SecretState as V1SecretState


class SecretState(Enum):
    STATE_UNSPECIFIED = "STATE_UNSPECIFIED"
    STATE_ACTIVE = "STATE_ACTIVE"
    STATE_DELETED = "STATE_DELETED"

    def to_api_object(self) -> V1SecretState:
        return V1SecretState(self.name)


def from_api_object(kernel_state: V1SecretState) -> SecretState:
    return SecretState(str(kernel_state))



import http

import pytest

''
from h2o_secure_store.clients.secret.client import SecretClient
from h2o_secure_store.clients.secret_version.client import SecretVersionClient
from h2o_secure_store.clients.secret_version.secret_version import SecretVersion
from h2o_secure_store.exception import CustomApiException


@pytest.mark.parametrize(
    ["page_size", "page_token"],
    [
        (-20, ""),
        (0, "non-existing-token"),
    ],
)
def test_list_validation(user_secret_version_client, secret_user, page_size, page_token):
    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.list_secret_versions(
            parent=secret_user.name,
            page_size=page_size,
            page_token=page_token,
        )
    assert exc.value.status == http.HTTPStatus.BAD_REQUEST


def test_list_secret_versions_pagination(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    assert_list_secret_versions_pagination(
        secret_name=secret_user.name,
        secret_version_client_tested=user_secret_version_client,
    )


def test_list_all_secret_versions(delete_secret_rows_before,
                                  secret_user,
                                  user_secret_version_client: SecretVersionClient):
    # Arrange
    create_testing_secrets(
        secret_name=secret_user.name,
        secret_version_client_creator=user_secret_version_client,
    )

    # Test basic list_all.
    secrets = user_secret_version_client.list_all_secret_versions(
        parent=secret_user.name,
    )
    assert len(secrets) == 3


def test_list_secret_versions_deleted_secret(delete_secret_rows_before,
                                             secret_user,
                                             user_secret_client: SecretClient,
                                             user_secret_version_client: SecretVersionClient):
    create_testing_secrets(
        secret_name=secret_user.name,
        secret_version_client_creator=user_secret_version_client,
    )
    user_secret_client.delete_secret(name=secret_user.name)

    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.list_secret_versions(parent=secret_user.name, page_size=100, show_deleted=False)
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def assert_list_secret_versions_pagination(
        secret_name: str,
        secret_version_client_tested: SecretVersionClient,
):
    # Test no secrets found.
    page = secret_version_client_tested.list_secret_versions(parent=secret_name)
    assert len(page.secret_versions) == 0
    assert page.next_page_token == ""

    # Arrange
    create_testing_secrets(secret_name, secret_version_client_tested)

    # Test getting first page.
    page = secret_version_client_tested.list_secret_versions(
        parent=secret_name,
        page_size=1,
    )
    assert len(page.secret_versions) == 1
    assert page.next_page_token != ""

    # Test getting second page.
    page = secret_version_client_tested.list_secret_versions(
        parent=secret_name,
        page_size=1,
        page_token=page.next_page_token,
    )
    assert len(page.secret_versions) == 1
    assert page.next_page_token != ""

    # Test getting last page.
    page = secret_version_client_tested.list_secret_versions(
        parent=secret_name,
        page_size=1,
        page_token=page.next_page_token,
    )
    assert len(page.secret_versions) == 1
    assert page.next_page_token == ""

    # Test exceeding max page size.
    page = secret_version_client_tested.list_secret_versions(
        parent=secret_name,
        page_size=1001,
    )
    assert len(page.secret_versions) == 3
    assert page.next_page_token == ""


def create_testing_secrets(secret_name: str, secret_version_client_creator: SecretVersionClient):
    secret_version_client_creator.create_secret_version(
        parent=secret_name,
        secret_version=SecretVersion(
            value=b"secret_value1"
        ),
    )
    secret_version_client_creator.create_secret_version(
        parent=secret_name,
        secret_version=SecretVersion(
            value=b"secret_value2"
        ),
    )
    secret_version_client_creator.create_secret_version(
        parent=secret_name,
        secret_version=SecretVersion(
            value=b"secret_value3"
        ),
    )



import http

import pytest

from h2o_secure_store.exception import CustomApiException


def test_delete_oauth_client(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
):
    super_admin_oauth_client_client.create_oauth_client(
        issuer="issuer1",
        client_id="client1",
        oauth_client_id="oauth-client1",
        authorization_endpoint="authz-endpoint",
        token_endpoint="token-endpoint",
    )

    super_admin_oauth_client_client.delete_oauth_client(
        oauth_client_id="oauth-client1",
    )

    with pytest.raises(CustomApiException) as exc:
        super_admin_oauth_client_client.get_oauth_client(
            oauth_client_id="oauth-client1",
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_delete_oauth_client_not_found(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
):
    with pytest.raises(CustomApiException) as exc:
        super_admin_oauth_client_client.delete_oauth_client(
            oauth_client_id="non-existing",
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND



import http

import pytest

from h2o_secure_store.clients.base.workspace import DEFAULT_WORKSPACE
from h2o_secure_store.clients.secret.client import SecretClient
from h2o_secure_store.exception import CustomApiException


@pytest.mark.parametrize(
    ["page_size", "page_token"],
    [
        (-20, ""),
        (0, "non-existing-token"),
    ],
)
def test_list_validation(user_secret_client, page_size, page_token):
    with pytest.raises(CustomApiException) as exc:
        user_secret_client.list_secrets(
            parent=DEFAULT_WORKSPACE,
            page_size=page_size,
            page_token=page_token,
        )
    assert exc.value.status == http.HTTPStatus.BAD_REQUEST


def test_list_secrets_pagination(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
):
    assert_list_secrets_pagination(
        secret_client_tested=user_secret_client,
    )


def test_list_all_secrets(delete_secret_rows_before,
                          user_secret_client: SecretClient):
    # Arrange
    create_testing_secrets(secret_client_creator=user_secret_client)

    # Test basic list_all.
    secrets = user_secret_client.list_all_secrets(
        parent=DEFAULT_WORKSPACE,
    )
    assert len(secrets) == 3


def test_list_all_secrets_workspace_separation(delete_secret_rows_before,
                                               user_secret_client: SecretClient,
                                               super_admin_secret_client: SecretClient):
    # Arrange
    create_testing_secrets(secret_client_creator=user_secret_client)

    # Test basic list_all as a different user.
    secrets = super_admin_secret_client.list_all_secrets(
        parent=DEFAULT_WORKSPACE,
    )
    assert len(secrets) == 0


def test_list_secrets_show_deleted(delete_secret_rows_before,
                                   user_secret_client: SecretClient):
    create_testing_secrets(secret_client_creator=user_secret_client)
    create_testing_secrets_deleted(secret_client_creator=user_secret_client)

    secrets = user_secret_client.list_secrets(parent=DEFAULT_WORKSPACE, page_size=100, show_deleted=False)
    assert len(secrets.secrets) == 3

    secrets = user_secret_client.list_secrets(parent=DEFAULT_WORKSPACE, page_size=100, show_deleted=True)
    assert len(secrets.secrets) == 6


def assert_list_secrets_pagination(
        secret_client_tested: SecretClient,
):
    # Test no secrets found.
    page = secret_client_tested.list_secrets(parent=DEFAULT_WORKSPACE)
    assert len(page.secrets) == 0
    assert page.next_page_token == ""

    # Arrange
    create_testing_secrets(secret_client_tested)

    # Test getting first page.
    page = secret_client_tested.list_secrets(
        parent=DEFAULT_WORKSPACE,
        page_size=1,
    )
    assert len(page.secrets) == 1
    assert page.next_page_token != ""

    # Test getting second page.
    page = secret_client_tested.list_secrets(
        parent=DEFAULT_WORKSPACE,
        page_size=1,
        page_token=page.next_page_token,
    )
    assert len(page.secrets) == 1
    assert page.next_page_token != ""

    # Test getting last page.
    page = secret_client_tested.list_secrets(
        parent=DEFAULT_WORKSPACE,
        page_size=1,
        page_token=page.next_page_token,
    )
    assert len(page.secrets) == 1
    assert page.next_page_token == ""

    # Test exceeding max page size.
    page = secret_client_tested.list_secrets(
        parent=DEFAULT_WORKSPACE,
        page_size=1001,
    )
    assert len(page.secrets) == 3
    assert page.next_page_token == ""


def create_testing_secrets(secret_client_creator: SecretClient):
    secret_client_creator.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1",
    )
    secret_client_creator.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret2",
    )
    secret_client_creator.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret3",
    )


def create_testing_secrets_deleted(secret_client_creator: SecretClient):
    s1 = secret_client_creator.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1-delete",
    )
    secret_client_creator.delete_secret(name=s1.name)
    s2 = secret_client_creator.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret2-delete",
    )
    secret_client_creator.delete_secret(name=s2.name)
    s3 = secret_client_creator.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret3-delete",
    )
    secret_client_creator.delete_secret(name=s3.name)



import pprint
from datetime import datetime
from typing import Optional

from h2o_secure_store.gen.model.v1_token_source import V1TokenSource


class TokenSource:
    def __init__(
            self,
            name: str,
            redirect_uri: str,
            login_uri: str,
            login_required: bool,
            access_token: str,
            issue_time: Optional[datetime],
            expire_time: datetime,
            subject: str,
            login_principal: str,
            creator: str,
            uid: str,
            create_time: datetime,
            login_time: Optional[datetime],
    ):
        self.name = name
        self.redirect_uri = redirect_uri
        self.login_uri = login_uri
        self.login_required = login_required
        self.access_token = access_token
        self.issue_time = issue_time
        self.expire_time = expire_time
        self.subject = subject
        self.login_principal = login_principal
        self.creator = creator
        self.uid = uid
        self.create_time = create_time
        self.login_time = login_time

        self.oauth_client_id = ""
        self.token_source_id = ""
        if name:
            self.oauth_client_id = self.name.split("/")[1]
            self.token_source_id = self.name.split("/")[3]

    def __repr__(self) -> str:
        return pprint.pformat(self.__dict__)

    def to_api_object(self) -> V1TokenSource:
        return V1TokenSource(
            name=self.name,
            redirect_uri=self.redirect_uri,
            login_uri=self.login_uri,
            login_required=self.login_required,
            access_token=self.access_token,
            issue_time=self.issue_time,
            expire_time=self.expire_time,
            subject=self.subject,
            login_principal=self.login_principal,
            creator=self.creator,
            uid=self.uid,
            create_time=self.create_time,
            login_time=self.login_time,
        )


def from_api_object(api_object: V1TokenSource) -> TokenSource:
    return TokenSource(
        name=api_object.name,
        redirect_uri=api_object.redirect_uri,
        login_uri=api_object.login_uri,
        login_required=api_object.login_required,
        access_token=api_object.access_token,
        issue_time=api_object.issue_time,
        expire_time=api_object.expire_time,
        subject=api_object.subject,
        login_principal=api_object.login_principal,
        creator=api_object.creator,
        uid=api_object.uid,
        create_time=api_object.create_time,
        login_time=api_object.login_time,
    )



import ssl
from typing import Callable
from typing import Optional
from typing import Union
from urllib.parse import urljoin

import requests
from h2o_authn import TokenProvider

from h2o_secure_store.clients.connection_config import ConnectionConfig
from h2o_secure_store.clients.connection_config import discover_platform_connection
from h2o_secure_store.clients.connection_config import get_connection
from h2o_secure_store.clients.oauth_client.client import OAuthClientClient
from h2o_secure_store.clients.secret.client import SecretClient
from h2o_secure_store.clients.secret_version.client import SecretVersionClient
from h2o_secure_store.clients.token_source.client import TokenSourceClient


class Clients:
    def __init__(
        self,
        oauth_client_client: OAuthClientClient,
        token_source_client: TokenSourceClient,
        secret_client: SecretClient,
        secret_version_client: SecretVersionClient,
    ) -> None:
        self.oauth_client_client = oauth_client_client
        self.token_source_client = token_source_client
        self.secret_client = secret_client
        self.secret_version_client = secret_version_client


def login(
    environment: Optional[str] = None,
    token_provider: Optional[TokenProvider] = None,
    platform_token: Optional[str] = None,
    config_path: Optional[str] = None,
    verify_ssl: bool = True,
    ssl_ca_cert: Optional[str] = None,
) -> Clients:
    """Initializes Secure Store clients for H2O AI Cloud.

    All arguments are optional. Configuration-less login is dependent on having the H2O CLI configured.
    See: https://docs.h2o.ai/h2o-ai-cloud/developerguide/cli#platform-token
    The Discovery Service is used to discover the Secure Store server endpoint.
    See: https://pypi.org/project/h2o-cloud-discovery/

    Args:
        environment (str, optional): The H2O Cloud environment URL to use (e.g. https://cloud.h2o.ai).
            If left empty, the environment will be read from the H2O CLI configuration or environmental variables.
            Then, h2o-cloud-discovery will be used to discover the Secure Store API server endpoint.
        token_provider (TokenProvider, optional) = Token provider. Takes priority over platform_token argument.
        platform_token (str, optional): H2O Platform Token.
            If neither 'token_provider' nor 'platform_token' is provided the platform token will be read
            from the H2O CLI configuration.
        config_path: (str, optional): Path to the H2O AI Cloud configuration file.
            Defaults to '~/.h2oai/h2o-cli-config.toml'.
        verify_ssl: Set to False to disable SSL certificate verification.
        ssl_ca_cert: Path to a CA cert bundle with certificates of trusted CAs.

    Raises:
        FileNotFoundError: When the H2O CLI configuration file is needed but cannot be found.
        TomlDecodeError: When the H2O CLI configuration file is needed but cannot be processed.
        LookupError: When the service endpoint cannot be discovered.
        ConnectionError: When a communication with server failed.
    """
    ssl_context = ssl.create_default_context(cafile=ssl_ca_cert)  # Will use system store if None
    if not verify_ssl:
        ssl_context.check_hostname = False
        ssl_context.verify_mode = ssl.CERT_NONE

    cfg = discover_platform_connection(
        environment_url=environment,
        platform_token=platform_token,
        token_provider=token_provider,
        config_path=config_path,
        ssl_context=ssl_context,
    )

    return __init_clients(
        cfg=cfg, verify_ssl=verify_ssl, ssl_ca_cert=ssl_ca_cert,
    )


def login_custom(
    endpoint: str,
    refresh_token: str,
    issuer_url: str,
    client_id: str,
    client_secret: Optional[str] = None,
    verify_ssl: bool = True,
    ssl_ca_cert: Optional[str] = None,
) -> Clients:
    """Initializes Secure store clients using h2o_authn to construct a token provider.

    Args:
        endpoint (str): The Secure Store API server endpoint URL (e.g. https://secure-store.cloud.h2o.ai).
        refresh_token (str): The OIDC refresh token.
        issuer_url (str): The OIDC issuer URL.
        client_id (str): The OIDC Client ID that issued the 'refresh_token'.
        client_secret (str, optional): Optional OIDC Client Secret that issued the 'refresh_token'. Defaults to None.
        verify_ssl: Set to False to disable SSL certificate verification.
        ssl_ca_cert: Path to a CA cert bundle with certificates of trusted CAs.
    """
    # Remove trailing slash from the URL for the generated clients
    endpoint = endpoint.rstrip("/")
    cfg = get_connection(
        server_url=endpoint,
        refresh_token=refresh_token,
        issuer_url=issuer_url,
        client_id=client_id,
        client_secret=client_secret,
        verify_ssl=verify_ssl,
        ssl_ca_cert=ssl_ca_cert,
    )

    return __init_clients(
        cfg=cfg, verify_ssl=verify_ssl, ssl_ca_cert=ssl_ca_cert,
    )


def login_custom_with_token_provider(
    endpoint: str,
    token_provider: Callable[[], str],
    verify_ssl: bool = True,
    ssl_ca_cert: Optional[str] = None,
) -> Clients:
    """Initializes Secure store clients using a custom token provider.

    A token provider can be constructed using h2o_authn:
    token_provider = h2o_authn.TokenProvider(
        issuer_url=issuer_url,
        refresh_token=refresh_token,
        client_id=client_id,
        client_secret=client_secret,
    )

    Args:
        endpoint (str): The Secure Store API server endpoint URL (e.g. https://secure-store.cloud.h2o.ai).
        token_provider (Callable[[], str]): A callable that returns an OIDC access token.
        verify_ssl: Set to False to disable SSL certificate verification.
        ssl_ca_cert: Path to a CA cert bundle with certificates of trusted CAs.
    """
    # Remove trailing slash from the URL for the generated clients
    endpoint = endpoint.rstrip("/")
    # Test token refresh
    token_provider()
    cfg = ConnectionConfig(server_url=endpoint, token_provider=token_provider)

    return __init_clients(
        cfg=cfg, verify_ssl=verify_ssl, ssl_ca_cert=ssl_ca_cert,
    )


def __init_clients(
    cfg: ConnectionConfig,
    verify_ssl: bool,
    ssl_ca_cert: Optional[str],
):
    # Verify that the server is reachable
    version_url = urljoin(cfg.server_url, "version")

    verify_param: Union[bool, str]
    if verify_ssl:
        verify_param = True
        if ssl_ca_cert:
            verify_param = ssl_ca_cert
    else:
        verify_param = False

    resp = requests.get(version_url, verify=verify_param)
    if not (200 <= resp.status_code <= 299):
        raise ConnectionError(
            f"Server is not reachable. Status code: {resp.status_code}, Response body: {resp.text}"
        )

    oauth_client_client = OAuthClientClient(connection_config=cfg, verify_ssl=verify_ssl, ssl_ca_cert=ssl_ca_cert)
    token_source_client = TokenSourceClient(connection_config=cfg, verify_ssl=verify_ssl, ssl_ca_cert=ssl_ca_cert)
    secret_client = SecretClient(connection_config=cfg, verify_ssl=verify_ssl, ssl_ca_cert=ssl_ca_cert)
    secret_version_client = SecretVersionClient(connection_config=cfg, verify_ssl=verify_ssl, ssl_ca_cert=ssl_ca_cert)

    return Clients(
        oauth_client_client=oauth_client_client,
        token_source_client=token_source_client,
        secret_client=secret_client,
        secret_version_client=secret_version_client,
    )



from h2o_secure_store.clients.secret_version.client import SecretVersionClient
from h2o_secure_store.clients.secret_version.secret_version import SecretVersion


def test_create_secret_version(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    secret_version = user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )

    assert secret_version.name == f"workspaces/{secret_user.get_workspace_id()}/secrets/{secret_user.get_secret_id()}/versions/{secret_version.get_secret_version_id()}"
    assert secret_version.value == b""  # Value is not returned in the response.
    assert secret_version.creator != ""
    assert secret_version.create_time is not None
    assert secret_version.uid  != ""


def test_create_secret_version_generate_secret_version_id(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    v1 = user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )

    v2 = user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )

    assert v1.name != v2.name
    assert v1.get_secret_version_id() != v2.get_secret_version_id()




"""
    ai/h2o/securestore/v1/oauth_client.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from h2o_secure_store.gen.api_client import ApiClient, Endpoint as _Endpoint
from h2o_secure_store.gen.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from h2o_secure_store.gen.model.rpc_status import RpcStatus
from h2o_secure_store.gen.model.v1_create_secret_response import V1CreateSecretResponse
from h2o_secure_store.gen.model.v1_delete_secret_response import V1DeleteSecretResponse
from h2o_secure_store.gen.model.v1_get_secret_response import V1GetSecretResponse
from h2o_secure_store.gen.model.v1_list_secrets_response import V1ListSecretsResponse
from h2o_secure_store.gen.model.v1_secret import V1Secret
from h2o_secure_store.gen.model.v1_undelete_secret_response import V1UndeleteSecretResponse


class SecretServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.secret_service_create_secret_endpoint = _Endpoint(
            settings={
                'response_type': (V1CreateSecretResponse,),
                'auth': [],
                'endpoint_path': '/v1/{parent}/secrets',
                'operation_id': 'secret_service_create_secret',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'parent',
                    'secret',
                    'secret_id',
                ],
                'required': [
                    'parent',
                    'secret',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'parent',
                ]
            },
            root_map={
                'validations': {
                    ('parent',): {

                        'regex': {
                            'pattern': r'workspaces\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'parent':
                        (str,),
                    'secret':
                        (V1Secret,),
                    'secret_id':
                        (str,),
                },
                'attribute_map': {
                    'parent': 'parent',
                    'secret_id': 'secretId',
                },
                'location_map': {
                    'parent': 'path',
                    'secret': 'body',
                    'secret_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.secret_service_delete_secret_endpoint = _Endpoint(
            settings={
                'response_type': (V1DeleteSecretResponse,),
                'auth': [],
                'endpoint_path': '/v1/{name_1}',
                'operation_id': 'secret_service_delete_secret',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'name_1',
                ],
                'required': [
                    'name_1',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name_1',
                ]
            },
            root_map={
                'validations': {
                    ('name_1',): {

                        'regex': {
                            'pattern': r'workspaces\/[^\/]+\/secrets\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name_1':
                        (str,),
                },
                'attribute_map': {
                    'name_1': 'name_1',
                },
                'location_map': {
                    'name_1': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.secret_service_get_secret_endpoint = _Endpoint(
            settings={
                'response_type': (V1GetSecretResponse,),
                'auth': [],
                'endpoint_path': '/v1/{name_1}',
                'operation_id': 'secret_service_get_secret',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'name_1',
                ],
                'required': [
                    'name_1',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name_1',
                ]
            },
            root_map={
                'validations': {
                    ('name_1',): {

                        'regex': {
                            'pattern': r'workspaces\/[^\/]+\/secrets\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name_1':
                        (str,),
                },
                'attribute_map': {
                    'name_1': 'name_1',
                },
                'location_map': {
                    'name_1': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.secret_service_list_secrets_endpoint = _Endpoint(
            settings={
                'response_type': (V1ListSecretsResponse,),
                'auth': [],
                'endpoint_path': '/v1/{parent}/secrets',
                'operation_id': 'secret_service_list_secrets',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'parent',
                    'page_size',
                    'page_token',
                    'show_deleted',
                ],
                'required': [
                    'parent',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'parent',
                ]
            },
            root_map={
                'validations': {
                    ('parent',): {

                        'regex': {
                            'pattern': r'workspaces\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'parent':
                        (str,),
                    'page_size':
                        (int,),
                    'page_token':
                        (str,),
                    'show_deleted':
                        (bool,),
                },
                'attribute_map': {
                    'parent': 'parent',
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                    'show_deleted': 'showDeleted',
                },
                'location_map': {
                    'parent': 'path',
                    'page_size': 'query',
                    'page_token': 'query',
                    'show_deleted': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.secret_service_undelete_secret_endpoint = _Endpoint(
            settings={
                'response_type': (V1UndeleteSecretResponse,),
                'auth': [],
                'endpoint_path': '/v1/{name}:undelete',
                'operation_id': 'secret_service_undelete_secret',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'name',
                    'body',
                ],
                'required': [
                    'name',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name',
                ]
            },
            root_map={
                'validations': {
                    ('name',): {

                        'regex': {
                            'pattern': r'workspaces\/[^\/]+\/secrets\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name':
                        (str,),
                    'body':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                },
                'attribute_map': {
                    'name': 'name',
                },
                'location_map': {
                    'name': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def secret_service_create_secret(
        self,
        parent,
        secret,
        **kwargs
    ):
        """Creates a new Secret containing no SecretVersions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.secret_service_create_secret(parent, secret, async_req=True)
        >>> result = thread.get()

        Args:
            parent (str): Required. The resource name of the workspace to associate with the Secret. Format: `workspaces/*`  Authorization requires the following permission on the specified resource parent: * actions/securestore/secrets/CREATE
            secret (V1Secret): Required. The Secret resource to create.

        Keyword Args:
            secret_id (str): Optional. Specify the Secret ID, which will become a part of the Secret resource name. If not specified, the server will generate one.  It must: - be unique within the parent workspace - contain 1-63 characters - contain only lowercase alphanumeric characters or hyphen ('-') - start with an alphabetic character - end with an alphanumeric character  This matches a regular expression: `^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$`. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1CreateSecretResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['parent'] = \
            parent
        kwargs['secret'] = \
            secret
        return self.secret_service_create_secret_endpoint.call_with_http_info(**kwargs)

    def secret_service_delete_secret(
        self,
        name_1,
        **kwargs
    ):
        """Deletes a Secret and the child SecretVersions. A deleted secret is purged after 30 days but can be restored using the undelete method.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.secret_service_delete_secret(name_1, async_req=True)
        >>> result = thread.get()

        Args:
            name_1 (str): Required. The resource name of the Secret to delete. Format: `workspaces/*/secrets/*`  Authorization requires the following permission on the specified resource name: * `actions/securestore/secrets/DELETE`

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1DeleteSecretResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name_1'] = \
            name_1
        return self.secret_service_delete_secret_endpoint.call_with_http_info(**kwargs)

    def secret_service_get_secret(
        self,
        name_1,
        **kwargs
    ):
        """Gets metadata for a Secret.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.secret_service_get_secret(name_1, async_req=True)
        >>> result = thread.get()

        Args:
            name_1 (str): Required. The resource name of the Secret. Format: `secrets/*`  Authorization requires the following permission on the specified resource name: * `actions/securestore/secrets/GET`

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1GetSecretResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name_1'] = \
            name_1
        return self.secret_service_get_secret_endpoint.call_with_http_info(**kwargs)

    def secret_service_list_secrets(
        self,
        parent,
        **kwargs
    ):
        """Lists Secrets.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.secret_service_list_secrets(parent, async_req=True)
        >>> result = thread.get()

        Args:
            parent (str): Required. The resource name of the workspace associated with the Secrets. Format: `workspaces/*`  Authorization requires the following permission on the specified resource parent: * `actions/securestore/secrets/LIST`

        Keyword Args:
            page_size (int): Optional. The maximum number of results to be returned in a single page. If unspecified (or set to 0), the server decides the number of results to return. If the number is greater than 1000, it is capped at 1000.. [optional]
            page_token (str): Optional. Pagination token, returned in `ListSecretsResponse.next_page_token`.. [optional]
            show_deleted (bool): Optional. If set to true, deleted Secrets are included in the list.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1ListSecretsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['parent'] = \
            parent
        return self.secret_service_list_secrets_endpoint.call_with_http_info(**kwargs)

    def secret_service_undelete_secret(
        self,
        name,
        body,
        **kwargs
    ):
        """Undeletes a deleted Secret and the child SecretVersions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.secret_service_undelete_secret(name, body, async_req=True)
        >>> result = thread.get()

        Args:
            name (str): Required. The resource name of the Secret to undelete. Format: `workspaces/*/secrets/*`  Authorization requires the following permission on the specified resource parent: * actions/securestore/secrets/UNDELETE
            body (bool, date, datetime, dict, float, int, list, str, none_type):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1UndeleteSecretResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name'] = \
            name
        kwargs['body'] = \
            body
        return self.secret_service_undelete_secret_endpoint.call_with_http_info(**kwargs)




import http

import pytest

from h2o_secure_store.clients.base.workspace import DEFAULT_WORKSPACE
from h2o_secure_store.clients.secret.client import SecretClient
from h2o_secure_store.clients.secret.state import SecretState
from h2o_secure_store.exception import CustomApiException


def test_get_secret(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
):
    user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1",
    )

    secret = user_secret_client.get_secret(name=f"{DEFAULT_WORKSPACE}/secrets/secret1")

    assert secret.name == f"workspaces/{secret.get_workspace_id()}/secrets/secret1"
    assert secret.state == SecretState.STATE_ACTIVE
    assert secret.creator != ""
    assert secret.create_time is not None
    assert secret.delete_time is None
    assert secret.purge_time is None
    assert secret.deleter == ""
    assert secret.uid != ""


def test_get_secret_not_found(
        user_secret_client: SecretClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_client.get_secret(name=f"{DEFAULT_WORKSPACE}/secrets/non-existing")
    assert exc.value.status == http.HTTPStatus.NOT_FOUND



"""
    ai/h2o/securestore/v1/oauth_client.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from h2o_secure_store.gen.api_client import ApiClient, Endpoint as _Endpoint
from h2o_secure_store.gen.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from h2o_secure_store.gen.model.rpc_status import RpcStatus
from h2o_secure_store.gen.model.v1_create_token_source_response import V1CreateTokenSourceResponse
from h2o_secure_store.gen.model.v1_get_token_source_response import V1GetTokenSourceResponse
from h2o_secure_store.gen.model.v1_list_token_sources_response import V1ListTokenSourcesResponse
from h2o_secure_store.gen.model.v1_token_source import V1TokenSource


class TokenSourceServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.token_source_service_create_token_source_endpoint = _Endpoint(
            settings={
                'response_type': (V1CreateTokenSourceResponse,),
                'auth': [],
                'endpoint_path': '/v1/{parent}/tokenSources',
                'operation_id': 'token_source_service_create_token_source',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'parent',
                    'token_source',
                    'token_source_id',
                ],
                'required': [
                    'parent',
                    'token_source',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'parent',
                ]
            },
            root_map={
                'validations': {
                    ('parent',): {

                        'regex': {
                            'pattern': r'oauthClients\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'parent':
                        (str,),
                    'token_source':
                        (V1TokenSource,),
                    'token_source_id':
                        (str,),
                },
                'attribute_map': {
                    'parent': 'parent',
                    'token_source_id': 'tokenSourceId',
                },
                'location_map': {
                    'parent': 'path',
                    'token_source': 'body',
                    'token_source_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.token_source_service_delete_token_source_endpoint = _Endpoint(
            settings={
                'response_type': (bool, date, datetime, dict, float, int, list, str, none_type,),
                'auth': [],
                'endpoint_path': '/v1/{name_2}',
                'operation_id': 'token_source_service_delete_token_source',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'name_2',
                ],
                'required': [
                    'name_2',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name_2',
                ]
            },
            root_map={
                'validations': {
                    ('name_2',): {

                        'regex': {
                            'pattern': r'oauthClients\/[^\/]+\/tokenSources\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name_2':
                        (str,),
                },
                'attribute_map': {
                    'name_2': 'name_2',
                },
                'location_map': {
                    'name_2': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.token_source_service_get_token_source_endpoint = _Endpoint(
            settings={
                'response_type': (V1GetTokenSourceResponse,),
                'auth': [],
                'endpoint_path': '/v1/{name_3}',
                'operation_id': 'token_source_service_get_token_source',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'name_3',
                ],
                'required': [
                    'name_3',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'name_3',
                ]
            },
            root_map={
                'validations': {
                    ('name_3',): {

                        'regex': {
                            'pattern': r'oauthClients\/[^\/]+\/tokenSources\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'name_3':
                        (str,),
                },
                'attribute_map': {
                    'name_3': 'name_3',
                },
                'location_map': {
                    'name_3': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.token_source_service_list_token_sources_endpoint = _Endpoint(
            settings={
                'response_type': (V1ListTokenSourcesResponse,),
                'auth': [],
                'endpoint_path': '/v1/{parent}/tokenSources',
                'operation_id': 'token_source_service_list_token_sources',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'parent',
                    'page_size',
                    'page_token',
                ],
                'required': [
                    'parent',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'parent',
                ]
            },
            root_map={
                'validations': {
                    ('parent',): {

                        'regex': {
                            'pattern': r'oauthClients\/[^\/]+',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'parent':
                        (str,),
                    'page_size':
                        (int,),
                    'page_token':
                        (str,),
                },
                'attribute_map': {
                    'parent': 'parent',
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                },
                'location_map': {
                    'parent': 'path',
                    'page_size': 'query',
                    'page_token': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def token_source_service_create_token_source(
        self,
        parent,
        token_source,
        **kwargs
    ):
        """Creates a new TokenSource.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.token_source_service_create_token_source(parent, token_source, async_req=True)
        >>> result = thread.get()

        Args:
            parent (str): Required. OAuth Client resource name. Format: oAuthClients/{oauthClient}
            token_source (V1TokenSource): Required. The TokenSource resource to create.

        Keyword Args:
            token_source_id (str): Optional. Specify the TokenSource ID, which will become a part of the TokenSource resource name. If not specified, the server will generate one.  It must: - contain 1-63 characters - contain only lowercase alphanumeric characters or hyphen ('-') - start with an alphabetic character - end with an alphanumeric character  This matches a regular expression: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1CreateTokenSourceResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['parent'] = \
            parent
        kwargs['token_source'] = \
            token_source
        return self.token_source_service_create_token_source_endpoint.call_with_http_info(**kwargs)

    def token_source_service_delete_token_source(
        self,
        name_2,
        **kwargs
    ):
        """Deletes a TokenSource.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.token_source_service_delete_token_source(name_2, async_req=True)
        >>> result = thread.get()

        Args:
            name_2 (str): Required. TokenSource resource name. Format: oAuthClients/{oauthClient}/tokenSources/{tokenSource}

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            bool, date, datetime, dict, float, int, list, str, none_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name_2'] = \
            name_2
        return self.token_source_service_delete_token_source_endpoint.call_with_http_info(**kwargs)

    def token_source_service_get_token_source(
        self,
        name_3,
        **kwargs
    ):
        """Returns a specific TokenSource.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.token_source_service_get_token_source(name_3, async_req=True)
        >>> result = thread.get()

        Args:
            name_3 (str): Required. The name of the TokenSource to retrieve. Format: `oAuthClients/{oauthClient}/tokenSources/{tokenSource}`

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1GetTokenSourceResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['name_3'] = \
            name_3
        return self.token_source_service_get_token_source_endpoint.call_with_http_info(**kwargs)

    def token_source_service_list_token_sources(
        self,
        parent,
        **kwargs
    ):
        """Returns a collection of TokenSources.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.token_source_service_list_token_sources(parent, async_req=True)
        >>> result = thread.get()

        Args:
            parent (str): Required. OAuth Client resource name. Format: oAuthClients/{oauthClient}

        Keyword Args:
            page_size (int): Optional. Maximum number of TokenSources to return in a response. If unspecified (or set to 0), at most 50 TokenSources will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.. [optional]
            page_token (str): Optional. Leave unset to receive the initial page. To list any subsequent pages use the value of 'next_page_token' returned from the ListTokenSourcesResponse.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            V1ListTokenSourcesResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['parent'] = \
            parent
        return self.token_source_service_list_token_sources_endpoint.call_with_http_info(**kwargs)




import ssl
from typing import Callable
from typing import NamedTuple
from typing import Optional

import h2o_authn
import h2o_discovery
from h2o_authn import TokenProvider

# Name of the platform client in the discovery response.
PLATFORM_CLIENT_NAME = "platform"
# Name of the Secure Store API service in the discovery response.
SECURE_STORE_SERVICE_NAME = "secure-store"


class ConnectionConfig(NamedTuple):
    """Object holding connection configuration for the Secure Store API server."""

    server_url: str
    token_provider: Callable[[], str]


def get_connection(
    server_url: str,
    refresh_token: str,
    issuer_url: str,
    client_id: str,
    client_secret: Optional[str],
    verify_ssl: bool,
    ssl_ca_cert: Optional[str],
) -> ConnectionConfig:
    """Creates ConnectionConfig object. Initializes and tests token provider."""
    ssl_context = ssl.create_default_context(cafile=ssl_ca_cert)  # Will use system store if None
    if not verify_ssl:
        ssl_context.check_hostname = False
        ssl_context.verify_mode = ssl.CERT_NONE

    # init token provider
    tp = h2o_authn.TokenProvider(
        issuer_url=issuer_url,
        refresh_token=refresh_token,
        client_id=client_id,
        client_secret=client_secret,
        http_ssl_context=ssl_context,
    )
    # test token refresh
    tp()

    return ConnectionConfig(server_url=server_url, token_provider=tp)


def discover_platform_connection(
        environment_url: Optional[str] = None,
        config_path: Optional[str] = None,
        platform_token: Optional[str] = None,
        token_provider: Optional[TokenProvider] = None,
        ssl_context: Optional[ssl.SSLContext] = None,
) -> ConnectionConfig:
    """Creates ConnectionConfig object by discovering platform connection configuration using h2o_discovery.

    :param environment_url: Override for the URL of the environment passed to the discovery service.
    :param config_path: Override path to the h2o cli config file passed to the discovery service.
    :param platform_token: Platform token. If not provided, the token will be discovered.
    :param token_provider: Token provider. If not provided, the provider will be constructed from the discovered config.
    :param ssl_context: SSL context to use for the discovery client.
    """
    # Discover the Secure Store server URL
    d = h2o_discovery.discover(environment=environment_url, config_path=config_path, ssl_context=ssl_context)

    secure_store_service = d.services.get(SECURE_STORE_SERVICE_NAME)
    if secure_store_service is None:
        raise Exception("Secure Store API service is not registered in discovery service")

    secure_store_url = secure_store_service.uri
    if not secure_store_url:
        raise ConnectionError("Unable to discover Secure Store server URL connection value.")

    # If the token provider is provided, use it to construct the connection config.
    if token_provider is not None:
        # Test token refresh
        token_provider()
        return ConnectionConfig(server_url=secure_store_url, token_provider=token_provider)

    # If the token provider is not provided, construct it from the discovered config.
    if not platform_token:
        platform_client_credentials = d.credentials[PLATFORM_CLIENT_NAME]
        if platform_client_credentials is None:
            raise Exception("Platform client credentials are not available in discovery service")

        platform_token = platform_client_credentials.refresh_token

    if not platform_token:
        raise ValueError(
            "Please set the 'platform_token' argument or configure the H2O CLI."
        )

    # Discover client id
    platform_client = d.clients.get(PLATFORM_CLIENT_NAME)
    if platform_client is None:
        raise Exception("platform client is not registered in discovery service")

    client_id = platform_client.oauth2_client_id
    if not client_id:
        raise ConnectionError(
            "Unable to discover platform oauth2_client_id connection value."
        )

    tp = h2o_authn.TokenProvider(
        issuer_url=d.environment.issuer_url,
        client_id=client_id,
        refresh_token=platform_token,
        http_ssl_context=ssl_context,
    )
    # Test token refresh
    tp()

    return ConnectionConfig(server_url=secure_store_url, token_provider=tp)



import pprint

from h2o_secure_store.clients.secret.secret import from_api_object
from h2o_secure_store.gen.model.v1_list_secrets_response import V1ListSecretsResponse


class SecretsPage:
    """Class represents a list of Secrets together with a next_page_token for listing all Secrets."""

    def __init__(self, list_api_response: V1ListSecretsResponse) -> None:
        api_objects = list_api_response.secrets
        self.secrets = []
        for api_secret in api_objects:
            self.secrets.append(from_api_object(api_secret))

        self.next_page_token = list_api_response.next_page_token

    def __repr__(self) -> str:
        return pprint.pformat(self.__dict__)



import http

import pytest

from h2o_secure_store.clients.token_source.client import TokenSourceClient
from h2o_secure_store.clients.token_source.token_source import TokenSource
from h2o_secure_store.exception import CustomApiException


def test_get_token_source(
        delete_all_token_sources_before_after,
        token_source1: TokenSource,
        user_token_source_client: TokenSourceClient,
):
    got_token_source = user_token_source_client.get_token_source(oauth_client_id=token_source1.oauth_client_id,
                                                                 token_source_id=token_source1.token_source_id)

    assert token_source1.name == got_token_source.name
    assert token_source1.token_source_id == got_token_source.token_source_id
    assert token_source1.oauth_client_id == got_token_source.oauth_client_id
    assert token_source1.creator == got_token_source.creator
    assert token_source1.create_time == got_token_source.create_time
    assert token_source1.login_time == got_token_source.login_time
    assert token_source1.login_required == got_token_source.login_required
    assert token_source1.login_uri == got_token_source.login_uri
    assert token_source1.redirect_uri == got_token_source.redirect_uri
    assert token_source1.access_token == got_token_source.access_token
    assert token_source1.issue_time == got_token_source.issue_time
    assert token_source1.expire_time == got_token_source.expire_time
    assert token_source1.subject == got_token_source.subject
    assert token_source1.login_principal == got_token_source.login_principal
    assert token_source1.uid == got_token_source.uid


def test_get_token_source_not_found(
        delete_all_token_sources_before_after,
        token_source1: TokenSource,
        user_token_source_client: TokenSourceClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_token_source_client.get_token_source(
            token_source_id="non-existing", oauth_client_id=token_source1.oauth_client_id
        )

    assert exc.value.status == http.HTTPStatus.NOT_FOUND

    with pytest.raises(CustomApiException) as exc:
        user_token_source_client.get_token_source(
            token_source_id=token_source1.token_source_id, oauth_client_id="non-existing"
        )

    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_get_token_source_forbidden(
        delete_all_token_sources_before_after,
        token_source1: TokenSource,
        super_admin_token_source_client: TokenSourceClient,
):
    with pytest.raises(CustomApiException) as exc:
        # token_source1 is created with user_token_source_client - different user
        super_admin_token_source_client.get_token_source(
            token_source_id=token_source1.token_source_id, oauth_client_id=token_source1.oauth_client_id
        )
    assert exc.value.status == http.HTTPStatus.FORBIDDEN



# pip install https://secure-store-release.s3.amazonaws.com/latest-snapshot/downloads/h2o_secure_store-0.1.0-py3-none-any.whl
import h2o_secure_store

# This will work only when running in Notebook Lab or locally if you have H2O CLI configured.
# Otherwise you need to pass additional arguments to the login function.
# See the login function docstring for more information.
hss = h2o_secure_store.login()

# Administrator set-up.
# This part needs to be done once, as an administrator.
# It registers an OAuth client with the Secure Store.

# List existing clients to see if the client already exists.
hss.oauth_client_client.list_all_oauth_clients()

# Create a new OAuth client
snowflake_client = hss.oauth_client_client.create_oauth_client(
    display_name="Snowflake",
    issuer="https://dev-41714738.okta.com/oauth2/aush3dnts4AA4K0C85d7",
    client_id="0oah7v0o13gI1Peec5d7",
    client_secret="5rDBGiMbEHE1YN-nFzWAxiGAKf9Jmg5M1VLofcOAdHIyBJn2wgkvy1rxDoM4GhRU",
    extra_scopes=["profile", "email"],  # Strongly recommended. Do not include the openid or offline_access scopes here.
    refresh_disabled=False,  # Enable only when the offline_access scope is not granted.
    login_principal_claim="preferred_username"  # The ID Token claim that contains the "username".
)

# When created, there will be a callback_uri that needs to be added in the IDP as a valid redirect URI.
print(f"Callback URI: {snowflake_client.callback_uri}")

# Delete the OAuth client all it's child TokenSources.
# hss.oauth_client_client.delete_oauth_client(snowflake_client.oauth_client_id)

####################################################################################################
# End user portion

# List existing OAuth clients and let user to chose one.
oauth_clients = hss.oauth_client_client.list_all_oauth_clients()

# We will use the first client for this example.
oauth_client = oauth_clients[0]

# Create a new TokenSource under the existing OAuth client.
# You can optionally specify a redirect_uri where the user will be redirected after successful login.
# That can be useful for callback to the application, so it knows to fetch the newly populated token.
ts = hss.token_source_client.create_token_source(
    oauth_client_id=oauth_client.oauth_client_id,
    # redirect_uri="https://h2o.ai",  # Optional.
)

# The user must now visit this URL.
print(f"Visit this URL: {ts.login_uri}")

# When you know user has logged in, re-fetch the TokenSource.
# You can also poll if callback is not an option.
ts = hss.token_source_client.get_token_source(
    oauth_client_id=oauth_client.oauth_client_id,
    token_source_id=ts.token_source_id,
)

print(f"Token: {ts.access_token}")
print(f"Expiration: {ts.expire_time}")

# The token source will keep refreshing the token in the background as long as possible.
# Come back and re-fetch the TokenSource at expire_time.

ts = hss.token_source_client.get_token_source(
    oauth_client_id=oauth_client.oauth_client_id,
    token_source_id=ts.token_source_id,
)

# If refresh token was revoked, or we cannot refresh the token for some reason,
# the TokenSource.login_required flag will be set to True and you must direct user to
# the login_uri again.
if ts.login_required:
    print(f"Login required: {ts.login_required}")
    print(f"Visit this URL: {ts.login_uri}")
else:
    print(f"Token: {ts.access_token}")
    print(f"Expiration: {ts.expire_time}")

# You can also list existing token sources.
hss.token_source_client.list_all_token_sources(oauth_client_id=oauth_client.oauth_client_id)

# You can also delete the TokenSource.
hss.token_source_client.delete_token_source(
    oauth_client_id=oauth_client.oauth_client_id,
    token_source_id=ts.token_source_id,
)




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from h2o_secure_store.gen.api.o_auth_client_service_api import OAuthClientServiceApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from h2o_secure_store.gen.api.o_auth_client_service_api import OAuthClientServiceApi
from h2o_secure_store.gen.api.secret_service_api import SecretServiceApi
from h2o_secure_store.gen.api.secret_version_service_api import SecretVersionServiceApi
from h2o_secure_store.gen.api.token_source_service_api import TokenSourceServiceApi



import time

from h2o_secure_store.clients.secret_version.client import SecretVersionClient
from h2o_secure_store.clients.secret_version.secret_version import SecretVersion


def test_reveal_secret_version_rotated_key(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    v = user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )

    user_secret_version_client.reveal_secret_version_value(
        name=v.name
    )

    # Wait for the key to be rotated
    time.sleep(5)

    user_secret_version_client.reveal_secret_version_value(
        name=v.name
    )


import http

import pytest

from h2o_secure_store.exception import CustomApiException


def test_get_oauth_client(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
    oauth_client1,
):
    got_oauth_client = super_admin_oauth_client_client.get_oauth_client(oauth_client_id="oauth-client1")

    assert oauth_client1.issuer == got_oauth_client.issuer
    assert oauth_client1.client_id == got_oauth_client.client_id
    assert oauth_client1.name == got_oauth_client.name
    assert oauth_client1.display_name == got_oauth_client.display_name
    assert oauth_client1.client_secret == got_oauth_client.client_secret
    assert oauth_client1.client_secret_set == got_oauth_client.client_secret_set
    assert oauth_client1.authorization_endpoint == got_oauth_client.authorization_endpoint
    assert oauth_client1.token_endpoint == got_oauth_client.token_endpoint
    assert oauth_client1.extra_scopes == got_oauth_client.extra_scopes
    assert oauth_client1.refresh_disabled == got_oauth_client.refresh_disabled
    assert oauth_client1.login_principal_claim == got_oauth_client.login_principal_claim
    assert oauth_client1.callback_uri == got_oauth_client.callback_uri
    assert oauth_client1.creator == got_oauth_client.creator
    assert oauth_client1.updater == got_oauth_client.updater
    assert oauth_client1.create_time == got_oauth_client.create_time
    assert oauth_client1.update_time == got_oauth_client.update_time
    assert oauth_client1.uid == got_oauth_client.uid


def test_get_oauth_client_not_found(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
):
    with pytest.raises(CustomApiException) as exc:
        super_admin_oauth_client_client.get_oauth_client(
            oauth_client_id="non-existing"
        )

    assert exc.value.status == http.HTTPStatus.NOT_FOUND
